@@ -70,117 +70,127 @@
 <context>
     <name>Data</name>
     <message>
-        <location filename="../src/data/data.cpp" line="228"/>
+        <location filename="../src/data/data.cpp" line="234"/>
         <source>Supported files</source>
         <translation>Tuetut tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="229"/>
+        <location filename="../src/data/data.cpp" line="235"/>
         <source>CSV files</source>
         <translation>CSV-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="230"/>
+        <location filename="../src/data/data.cpp" line="236"/>
         <source>CUP files</source>
         <translation>CUP-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="231"/>
+        <location filename="../src/data/data.cpp" line="237"/>
         <source>FIT files</source>
         <translation>FIT-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="232"/>
+        <location filename="../src/data/data.cpp" line="238"/>
         <source>GeoJSON files</source>
         <translation>GeoJSON-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="233"/>
+        <location filename="../src/data/data.cpp" line="239"/>
         <source>GPI files</source>
         <translation>GPI-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="234"/>
+        <location filename="../src/data/data.cpp" line="240"/>
         <source>GPX files</source>
         <translation>GPX-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="235"/>
+        <location filename="../src/data/data.cpp" line="241"/>
         <source>IGC files</source>
         <translation>IGC-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="236"/>
+        <location filename="../src/data/data.cpp" line="242"/>
         <source>ITN files</source>
         <translation>ITN-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="237"/>
+        <location filename="../src/data/data.cpp" line="243"/>
         <source>JPEG images</source>
         <translation>JPEG-kuvat</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="238"/>
+        <location filename="../src/data/data.cpp" line="244"/>
         <source>KML files</source>
         <translation>KML-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="239"/>
+        <location filename="../src/data/data.cpp" line="245"/>
         <source>LOC files</source>
         <translation>LOC-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="240"/>
+        <location filename="../src/data/data.cpp" line="246"/>
         <source>NMEA files</source>
         <translation>NMEA-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="242"/>
+        <location filename="../src/data/data.cpp" line="248"/>
         <source>OV2 files</source>
         <translation>OV2-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="243"/>
+        <location filename="../src/data/data.cpp" line="249"/>
         <source>OziExplorer files</source>
         <translation>OziExplorer-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="245"/>
+        <location filename="../src/data/data.cpp" line="251"/>
         <source>SML files</source>
         <translation>SML-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="246"/>
+        <location filename="../src/data/data.cpp" line="252"/>
         <source>TCX files</source>
         <translation>TCX-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="244"/>
+        <location filename="../src/data/data.cpp" line="250"/>
         <source>SLF files</source>
         <translation>SLF-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="241"/>
+        <location filename="../src/data/data.cpp" line="247"/>
         <source>ONmove files</source>
         <translation>ONmove-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="247"/>
+        <location filename="../src/data/data.cpp" line="253"/>
         <source>70mai GPS log files</source>
+        <translation>70mai GPS -lokitiedostot</translation>
+    </message>
+    <message>
+        <location filename="../src/data/data.cpp" line="254"/>
+        <source>VKX files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="248"/>
+        <location filename="../src/data/data.cpp" line="255"/>
+        <source>VTK files</source>
+        <translation>VTK-tiedostot</translation>
+    </message>
+    <message>
+        <location filename="../src/data/data.cpp" line="256"/>
         <source>TwoNav files</source>
         <translation>TwoNav-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="249"/>
+        <location filename="../src/data/data.cpp" line="257"/>
         <source>GPSDump files</source>
         <translation>GPSDump-tiedostot</translation>
     </message>
     <message>
-        <location filename="../src/data/data.cpp" line="250"/>
+        <location filename="../src/data/data.cpp" line="258"/>
         <source>All files</source>
         <translation>Kaikki tiedostot</translation>
     </message>
@@ -2380,7 +2390,7 @@
         <translation>Vauhti</translation>
     </message>
     <message>
-        <location filename="../src/GUI/speedgraph.cpp" line="140"/>
+        <location filename="../src/GUI/speedgraph.cpp" line="152"/>
         <source>km/h</source>
         <translation>km/t</translation>
     </message>
@@ -2425,12 +2435,12 @@
         <translation>Tahti</translation>
     </message>
     <message>
-        <location filename="../src/GUI/speedgraph.cpp" line="134"/>
+        <location filename="../src/GUI/speedgraph.cpp" line="146"/>
         <source>kn</source>
         <translation>kn</translation>
     </message>
     <message>
-        <location filename="../src/GUI/speedgraph.cpp" line="137"/>
+        <location filename="../src/GUI/speedgraph.cpp" line="149"/>
         <source>mi/h</source>
         <translation>mph</translation>
     </message>
