@@ -1,13 +1,11 @@
 #ifndef ROUTEITEM_H
 #define ROUTEITEM_H
 
-#include "data/route.h"
+#include "data/link.h"
 #include "pathitem.h"
-#include "units.h"
-#include "format.h"
-#include "graphicsscene.h"
 
 class Map;
+class Route;
 class WaypointItem;
 
 class RouteItem : public PathItem
@@ -18,22 +16,22 @@ public:
 	RouteItem(const Route &route, Map *map, QGraphicsItem *parent = 0);
 
 	void setMap(Map *map);
+	void setDigitalZoom(int zoom);
 
-	void setUnits(Units u);
-	void setCoordinatesFormat(CoordinatesFormat format);
 	void showWaypoints(bool show);
 	void showWaypointLabels(bool show);
+	void showWaypointIcons(bool show);
 
-	QString info() const;
+	ToolTip info(bool extended) const;
+	QDateTime date() const {return QDateTime();}
 
 private:
 	QString _name;
 	QString _desc;
 	QString _comment;
 	QVector<Link> _links;
-	CoordinatesFormat _coordinatesFormat;
-
 	QVector<WaypointItem*> _waypoints;
+	QString _file;
 };
 
 #endif // ROUTEITEM_H
