@@ -467,8 +467,7 @@ bool FITParser::parseHeader(CTX &ctx)
 }
 
 bool FITParser::parse(QFile *file, QList<TrackData> &tracks,
-  QList<RouteData> &routes,
-  QList<Area> &polygons, QVector<Waypoint> &waypoints)
+  QList<RouteData> &routes, QList<Area> &polygons, QVector<Waypoint> &waypoints)
 {
 	Q_UNUSED(routes);
 	Q_UNUSED(polygons);
