@@ -244,6 +244,101 @@ bool RGNFile::readLabel(Handle &hdl, LBLFile *lbl, Handle &lblHdl,
 	return true;
 }
 
+bool RGNFile::readLineStyle(Handle &hdl, quint8 flags, quint32 size,
+  MapData::Poly *line) const
+{
+	line->flags |= (flags & 0xf)<<24;
+
+	if (size == 1) {
+		quint32 val;
+
+		if (!readUInt8(hdl, val))
+			return false;
+
+		if (val & 3)
+			line->flags |= MapData::Poly::Dashed;
+		if ((val >> 3) & 3)
+			line->flags |= MapData::Poly::Direction;
+		if ((val >> 3) & 2)
+			line->flags |= MapData::Poly::Invert;
+
+		return true;
+	} else {
+		if ((flags >> 4) & 3)
+			line->flags |= MapData::Poly::Dashed;
+		return (!size);
+	}
+}
+
+bool RGNFile::readRecommendedRoute(Handle &hdl, quint8 flags, quint32 size,
+  MapData::Poly *line) const
+{
+	quint32 f2;
+
+	if (!(size >= 1 && readUInt8(hdl, f2)))
+		return false;
+	size--;
+
+	if ((flags >> 5) == 7) {
+		quint32 f3;
+		if (!(size >= 1 && readUInt8(hdl, f3)))
+			return false;
+		size--;
+
+		if (f3 & 1) {
+			quint32 v1;
+			if (!(size >= 1 && readUInt8(hdl, v1)))
+				return false;
+			size--;
+			if (v1 & 1) {
+				quint32 v2;
+				if (!(size >= 1 && readUInt8(hdl, v2)))
+					return false;
+				size--;
+			}
+		}
+		if (f3 & 2) {
+			quint32 angle;
+			if (!(size >= 2 && readUInt16(hdl, angle)))
+				return false;
+			size -= 2;
+			line->label = Label(QString::number(angle / 10.0) + QChar(0x00B0));
+		}
+		if (f3 & 4) {
+			quint32 v;
+			if (!(size >= 1 && readUInt8(hdl, v)))
+				return false;
+			size--;
+
+			if ((v >> 4) & 3) {
+				line->flags |= MapData::Poly::Dashed;
+				line->label = Label();
+			}
+		}
+	} else {
+		if ((f2 & 0xe)) {
+			quint32 angle;
+			if (!(size >= 2 && readUInt16(hdl, angle)))
+				return false;
+			size -= 2;
+			line->label = Label(QString::number(angle / 10.0) + QChar(0x00B0));
+		} else if (f2 & 0x70) {
+			quint32 v1;
+			if (!(size >= 1 && readUInt8(hdl, v1)))
+				return false;
+			size--;
+			if (v1 & 1) {
+				quint32 v2;
+				if (!(size >= 1 && readUInt8(hdl, v2)))
+					return false;
+				size--;
+			}
+		}
+	}
+
+	return (size == 0);
+}
+
 bool RGNFile::readClassFields(Handle &hdl, SegmentType segmentType,
   void *object, LBLFile *lbl, Handle &lblHdl) const
 {
@@ -251,6 +346,8 @@ bool RGNFile::readClassFields(Handle &hdl, SegmentType segmentType,
 	quint32 rs = 0;
 	MapData::Poly *poly = (segmentType == Polygon)
 	  ? (MapData::Poly *) object : 0;
+	MapData::Poly *line = (segmentType == Line)
+	  ? (MapData::Poly *) object : 0;
 	MapData::Point *point = (segmentType == Point)
 	  ? (MapData::Point *) object : 0;
 
@@ -277,9 +374,9 @@ bool RGNFile::readClassFields(Handle &hdl, SegmentType segmentType,
 
 	if (poly && Style::isRaster(poly->type))
 		readRasterInfo(hdl, lbl, rs, poly);
+
 	if (point && !Style::isMarinePoint(point->type))
 		readLabel(hdl, lbl, lblHdl, flags, rs, point);
-
 	if (point && Style::isDepthPoint(point->type))
 		readDepthInfo(hdl, flags, rs, point);
 	if (point && Style::isObstructionPoint(point->type))
@@ -288,6 +385,13 @@ bool RGNFile::readClassFields(Handle &hdl, SegmentType segmentType,
 		readBuoyInfo(hdl, flags, rs, point);
 	if (point && Style::isLight(point->type))
 		readLightInfo(hdl, flags, rs, point);
+	if (point && Style::isLabelPoint(point->type))
+		point->flags |= (flags & 0xf)<<20;
+
+	if (line && Style::isStyledLine(line->type))
+		readLineStyle(hdl, flags, rs, line);
+	if (line && Style::isRecommendedRoute(line->type))
+		readRecommendedRoute(hdl, flags, rs, line);
 
 	return seek(hdl, off + rs);
 }
@@ -597,8 +701,7 @@ bool RGNFile::polyObjects(Handle &hdl, const SubDiv *subdiv,
 		poly.type = (segmentType == Polygon)
 		  ? ((quint32)(type & 0x7F)) << 8 : ((quint32)(type & 0x3F)) << 8;
 		if (segmentType == Line && type & 0x40)
-			poly.oneway = true;
-
+			poly.flags |= MapData::Poly::OneWay;
 
 		QPoint pos(subdiv->lon() + LS(lon, 24-subdiv->bits()),
 		  subdiv->lat() + LS(lat, 24-subdiv->bits()));
